@@ -1,12 +1,5 @@
-##
-# name:      IO::All::File
-# author:    Ingy döt Net
-# abstract:  File Plugin For IO::All
-# license:   perl
-# copyright: 2004, 2006, 2008, 2010, 2012
-
 package IO::All::File;
-use IO::All::OO;
+use IO::All::Base;
 extends 'IO::All::Filesys';
 
 option 'utf8';
